/******************************************************************************
 *
 * biblesync-version.h - version constants.
 *
 * BibleSync library
 * Karl Kleinpaste, May 2014
 *
 * All files related to implementation of BibleSync, including program
 * source, READMEs, manual pages, and related similar documents, are in
 * the public domain.  As a matter of simple decency, your social
 * obligations are to credit the source and to coordinate any changes you
 * make back to the origin repository.  These obligations are non-
 * binding for public domain software, but they are to be seriously
 * handled nonetheless.
 */

#ifndef BIBLESYNC_VERSION_HH
#define BIBLESYNC_VERSION_HH

#define BIBLESYNC_VERSION_NUM 2001000000
#define BIBLESYNC_VERSION_STR "2.1.0"
#define BIBLESYNC_VERSION_MAJOR 2
#define BIBLESYNC_VERSION_MINOR 1
#define BIBLESYNC_VERSION_MICRO 0
#define BIBLESYNC_VERSION_NANO 0

#endif	// BIBLESYNC_VERSION_HH
